@@ -43,20 +43,16 @@ class DictDataset(torch.utils.data.Dataset):
         """
         raise NotImplementedError()
 
-    def __getitem__(self, idx: int) -> Mapping[str, torch.Tensor]:
-        """Returns a {"data": data, **self.load_target_dict(idx)} dataitem for a given integer key. 
-            
-        Every value has to be a torch.Tensor.
+    def __getitem__(self, idx: int) -> Mapping[str, Any]:
+        """Returns a {"data": data, **self.load_target_dict(idx)} dataitem for a given integer key.
 
-        Later torch.utils.data.DataLoader collates this dicts into a dict o batched tensors.
+        Later torch.utils.data.DataLoader collates this dicts into a dict o batched items.
         """
         data = self.load_data(idx)
         
         if self.transform:
             data = self.transform(data)
-        else:
-            data = transforms.ToTensor()(data)
-        
+
         return {"data": data, **self.load_target_dict(idx)}        
         
     def __len__(self) -> int:
