@@ -55,9 +55,15 @@ class Trainer(object):
         )
 
 
-    def _loop(self, model, optimizer=None, train=False, epoch="-"):
+    def eval_loop(self, model, loader=None):
+        loader = loader or self.val_loader
+        return self._loop(model, loader=loader)
+
+
+    def _loop(self, model, optimizer=None, train=False, loader=None, epoch="-"):
         meters = utils.DefaultDict(lambda _: utils.AverageMeter())
-        loader = self.train_loader if train else self.val_loader
+        if loader is None:
+            loader = self.train_loader if train else self.val_loader
         iterator = tqdm(iter(loader), total=len(loader))
         iterator.set_description(f"Epoch: {epoch}, {'Train' if train else 'VAL'}")
 
